==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/admin/referer.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
$head = "HTTP Referer";
include("auth.inc.php");
include("../include/header.inc.php");
$out = new KWL_Html;

if (isset($delete)) {
	/* clear record */
	SqlQuery("DELETE FROM T_Referer");
}

$limit = 50;
$display_limit = 60;
$total = SqlCount("T_Referer");
$totalhits = SqlResult("SELECT SUM(Hit) FROM T_Referer");
$result = SqlQuery("SELECT Url, Hit FROM T_Referer ORDER BY Hit DESC LIMIT $limit");

$VAR['Content'] = $out->table_start("100%",'',0,0,3) ."<TR><TD><B>Url</B></TD><TD><B>Hits</B></TD><TD><B>%</B></TD>";

while ($A = mysql_fetch_array($result)) {
	if ($A['Url'] != "direct") {
		if (strlen($A['Url']) > $display_limit) $tmp = substr($A['Url'],0,60) . "...";
		else $tmp = $A['Url'];
		$A['Url'] = "<A HREF=\"$A[Url]\" target=\"_blank\">$tmp</A>";
	}
	$VAR['Content'] .= "<TR><TD>$A[Url]</A></TD>";
	$VAR['Content'] .= "<TD>$A[Hit]</TD>";
	$VAR['Content'] .= "<TD>" . round(($A['Hit'] / $totalhits * 100), 2) . "</TD>";
}

$VAR['Content'] .= "</TR>". $out->table_end();
$VAR['Heading'] = "HTTP Referer";
KWL_DrawMain($VAR);

$VAR['Heading'] = "Control";
$VAR['Content'] = $out->form_start("admin/referer.php","referer")
. $out->table_start("100%") ."
<TR>
	<TD ALIGN=CENTER>
	Total: $total referer record " 
	. $out->input_form("SUBMIT",'',_LOG_RESET)
	. $out->input_form("HIDDEN","delete",1) ."</TD>
</TR>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/referer.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
$head = "HTTP Referer";
include("auth.inc.php");
include("../include/header.inc.php");
$out = new KWL_Html;

if (isset($delete)) {
	/* clear record */
	SqlQuery("DELETE FROM T_Referer");
}

$total = SqlCount("T_Referer");
if (isset($show)) $limit = $total;
else $limit = "50";
$display_limit = 60;
$totalhits = SqlResult("SELECT SUM(Hit) FROM T_Referer");
$result = SqlQuery("SELECT Url, Hit FROM T_Referer ORDER BY Hit DESC LIMIT $limit");

$VAR['Content'] = $out->table_start("100%",'',0,0,3) ."<TR><TD><B>Url</B></TD><TD><B>Hits</B></TD><TD><B>%</B></TD>";

while ($A = mysql_fetch_array($result)) {
	if ($A['Url'] != "direct") {
		if (strlen($A['Url']) > $display_limit) $tmp = substr($A['Url'],0,60) . "...";
		else $tmp = $A['Url'];
		$A['Url'] = "<A HREF=\"$A[Url]\" target=\"_blank\">$tmp</A>";
	}
	$VAR['Content'] .= "<TR><TD>$A[Url]</A></TD>";
	$VAR['Content'] .= "<TD>$A[Hit]</TD>";
	$VAR['Content'] .= "<TD>" . round(($A['Hit'] / $totalhits * 100), 2) . "</TD>";
}

$VAR['Content'] .= "</TR>". $out->table_end();
$VAR['Heading'] = "HTTP Referer";
KWL_DrawMain($VAR);

$VAR['Heading'] = "Control";
$VAR['Content'] = $out->form_start("admin/referer.php","referer")
. $out->table_start("100%") ."
<TR>
	<TD ALIGN=CENTER>
	Total: $total referer record ".
   (($total > $limit) ? "(<a href=\"referer.php?show=all\">". _SHOW_ALL ."</a>)" : "") .
	$out->input_form("SUBMIT",'',_LOG_RESET) .
	$out->input_form("HIDDEN","delete",1) ."</TD>
</TR>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>
